#
# spec file for package bmake
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           bmake
Version:        20160528
Release:        1.1
Summary:        The NetBSD make(1) tool
License:        BSD-2-Clause and BSD-3-Clause and BSD-4-Clause
Group:          Development/Tools/Building
Url:            ftp://ftp.NetBSD.org/pub/NetBSD/misc/sjg/
Source0:        ftp://ftp.NetBSD.org/pub/NetBSD/misc/sjg/bmake-%{version}.tar.gz
Source1:        Linux.sys.mk

%description
bmake, the NetBSD make(1) tool, is a program designed to simplify the
maintenance of other programs.  The input of bmake is a list of specifications
indicating the files upon which the targets (programs and other files) depend.
bmake then detects which targets are out of date based on their dependencies
and triggers the necessary commands to bring them up to date when that happens.

bmake is similar to GNU make, even though the syntax for the advanced features
supported in Makefiles is very different.

%prep
%setup -q -n %{name}

%build
unset MAKEFLAGS
env CFLAGS="%{optflags}" \
./boot-strap -o Linux \
  --prefix="%{_prefix}" \
  --sysconfdir="%{_sysconfdir}" \
  --with-default-sys-path="%{_datadir}/mk" \
  --mksrc none op=build

%install
install -Dp -m0644 bmake.1      %{buildroot}%{_mandir}/man1/bmake.1
install -Dp -m0755 Linux/bmake  %{buildroot}%{_bindir}/bmake
install -Dp -m0644 %{SOURCE1}   %{buildroot}%{_datadir}/mk/sys.mk

%check
./boot-strap op=test

%files
%defattr(-,root,root)
%doc ChangeLog README
%{_bindir}/bmake
%{_mandir}/man1/bmake.1%{ext_man}
%{_datadir}/mk/

%changelog
* Tue Jun 14 2016 dap.darkness@gmail.com
- 20160528
  * boot-strap, make-bootstrap.sh.in: Makefile uses _MAKE_VERSION
- Removed bmake-MAKE_VERSION.diff so.
* Thu May 26 2016 dap.darkness@gmail.com
- Added bmake-MAKE_VERSION.diff to fix MAKE_VERSION variable
  that fixes mk-configure package configure error.
* Wed May 25 2016 dap.darkness@gmail.com
- 20160512
  * Merge with NetBSD make, pick up
    + meta.c: ignore paths that match .MAKE.META.IGNORE_PATTERNS
    this is useful for gcov builds.
    + propagate errors from filemon(4).
    + remove use of non-standard types u_int etc.
    + meta.c: apply realpath() before matching against metaIgnorePaths
    + allow makefile to set .MAKE.JOBS
  * Makefile (PROG_NAME): use ${_MAKE_VERSION}
* Sun May 15 2016 dap.darkness@gmail.com
- 20160315
  * Merge with NetBSD make, pick up:
    + fix handling of archive members;
    + meta.c: treat missing Read file same as Write,
    in case we Delete it.
  * Rename variable to avoid interference
    with checks for ${MAKE_VERSION}.
* Wed Mar 16 2016 mpluskal@suse.com
- 20160307
  * Merge with NetBSD make, pick up
    + var.c: fix :ts\nnn to be octal by default.
    + meta.c: meta_finish() to cleanup memory.
    + meta.c: allow meta file for makeDepend if makefiles want it.
    + var.c: add knob to control handling of '$$' in :=
    + var.c: add .export-literal allows us to fix sys.clean-env.mk
    post the changes to Var_Subst. Var_Subst now takes flags, and
    does not consume '$$' in :=
    + ar.c: preserve '$$' in :=
    + parse.c: add .dinclude for handling included makefile like
    .depend
- Use correct package group
* Sun Dec 27 2015 mpluskal@suse.com
- Update to 20151220
  * suff.c: re-initialize suffNull when clearing suffixes.
  * cond.c: CondCvtArg: avoid access beyond end of empty buffer.
  * meta.c: meta_oodate: use lstat(2) for checking link target in
    case it is a symlink.
  * var.c: avoid calling brk_string and Var_Export1 with empty
    strings.
* Sat Nov 14 2015 mpluskal@suse.com
- Update to 20151022
  * Makefile (MAKE_VERSION): 20151022
  * Add support for BSD/OS which lacks inttypes.h
    and really needs sys/param.h for sys/sysctl.h
    also 'type' is not a shell builtin.
  * var.c: eliminate uint32_t and need for inttypes.h
  * main.c: PrintOnError flush stdout before run .ERROR
  * parse.c: cope with _SC_PAGESIZE not being defined.
- For reso of changes see Changelog
- Tiny spec file polishing
* Mon Oct  5 2015 mpluskal@suse.com
- Update to 20150910
  * Merge with NetBSD make, pick up
    + main.c: with -w print Enter/Leaving messages for objdir too
    if necessary.
    + centralize shell metachar handling
  * FILES: add metachar.[ch]
* Wed Aug  5 2015 mpluskal@suse.com
- Update to 20150606
  * Merge with NetBSD make, pick up
    + o make.1: document .OBJDIR target
* Sun May 17 2015 dap.darkness@gmail.com
- Update to 20150505:
  * Merge with NetBSD make, pick up
    + cond.c: be strict about lhs of comparison when evaluating .if
    but less so when called from variable expansion.
    + unit-tests/cond2.mk: test various error conditions
    + job.c: use memmove() rather than memcpy()
    + document different handling of '-' in jobs mode vs compat
    + fix jobs mode so that '-' only applies to whole job
    when shell lacks hasErrCtl
    + meta.c: use separate vars to track lcwd and latestdir (read)
    per process
    + meta.c: close meta file in child
  * Add Bitrig patch from joerg@netbsd.org
  * Makefile: use BINDIR.bmake if set. Same for MANDIR and
    SHAREDIR. Handy for testing release candidates in various
    environments.
  * move initialization of savederr to block where it is used
    to avoid spurious warning from gcc5
* Fri Mar  6 2015 mpluskal@suse.com
- Cleanups spec file with spec-cleaner
- Update to 20141111
  * Makefile (MAKE_VERSION): 20141111 just a cooler number
  * Makefile (MAKE_VERSION): 20141105
  * Merge with NetBSD make, pick up
  - revert major overhaul of suffix handling and POSIX compliance
  - too much breakage and impossible to make backwards
    compatible.
  - we still have the new unit test structure which is ok.
  - meta.c ensure "-- filemon" is at start of line.
  * configure.in: test that result of getconf PATH_MAX is numeric
    and discard if not.  Apparently needed for Hurd.
  * Makefile (MAKE_VERSION): 20140830
  * Merge with NetBSD make, pick up
  - major overhaul of suffix handling
  - improved POSIX compliance
  - overhauled unit-tests
* Sat Sep 13 2014 vle@gmx.net
- Update to 20140620.
- Enabled unit tests.
* Sun Jun  1 2014 dap.darkness@gmail.com
- Imported from repoforge.
- SUSEficated.
* Mon Jan  2 2012 cheusov@NetBSD.org
- Update to 20111010 and adapted to Repoforge.
* Tue Dec  8 2009 lav@altlinux.ru
- add pkgsrc-mk-files require
* Wed Jul 29 2009 lav@altlinux.ru
- create dir for bmake macros
* Thu Jul 23 2009 vle@gmx.net
- Now bmake doesn't depend on mk-files
* Sun Jul 12 2009 lav@altlinux.ru
- initial build for ALT Linux Sisyphus
* Mon Feb 23 2009 rel-eng@lists.fedoraproject.org
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild
* Wed Jul  2 2008 jmmv@NetBSD.org
- Initial release for Fedora.
